# Changelog

All notable changes to this project will be documented in this file.

## [0.10.0] - 2024-12-06

### 🚀 Features

- *(cook)* Every cookbook will now pull down notebook, app.py, README, and requirements

## [0.9.5] - 2024-12-06

### 🐛 Bug Fixes

- *(log)* Stopped duplicate logging

## [0.9.4] - 2024-12-06

### 🐛 Bug Fixes

- *(build)* Fixed port to 8001

## [0.9.3] - 2024-12-06

### ⚙️ Miscellaneous Tasks

- *(dockerfile)* Building base image

## [0.9.1] - 2024-12-06

### ⚙️ Miscellaneous Tasks

- *(build)* Refined kitchenai build

## [0.9.0] - 2024-12-06

### 🚀 Features

- *(cli)* Tested lightweight cli client

## [0.8.0] - 2024-12-05

### 🚀 Features

- *(cli)* Jupyter to kitchenai module conversion
- *(jupyter)* Base endpoints for jupyter notebook integration magic commands

### 🚜 Refactor

- *(cli)* Removed cooked notebook from hackathon; cleaned up init command; added collectstatic to init
- *(sdk)* Removed django ninja router. defined a set of simple routes

### 📚 Documentation

- *(readme)* Updated readme
- *(readme)* Chore updated readme
- *(deploy)* Added docker compose example
- *(readme)* Fix

## [0.7.0] - 2024-11-19

### 🚀 Features

- *(admin)* Access to django manage command from cli

### 📚 Documentation

- *(updated)* Updated all docs

## [0.6.0] - 2024-11-18

### 🚀 Features

- *(api)* Default file CRUD
- *(telemetry)* Added posthog anonymous telemetry usage data
- *(embed)* Embed crud endpoints with background workers

### 🚜 Refactor

- *(api)* Stable endpoints, query, agents
- *(api)* Removed agent handler. just query and storage

## [0.4.0] - 2024-11-14

### 🚜 Refactor

- *(metadata)* Refactor metadata on task, removed async streaming

### ⚙️ Miscellaneous Tasks

- *(build)* Easier publish to pypi

## [0.3.2] - 2024-11-12

### 🚜 Refactor

- *(core)* Fixed bug for core app qcluster; KITCHENAI_DEBUG

## [0.3.1] - 2024-11-11

### 📦 Build

- *(deps.resend)* Changed email provider from ses to resend
- *(settings)* KITCHENAI_DEBUG as an application var

## [0.3.0] - 2024-11-11

### 🚀 Features

- *(storage)* Q workers with storage decorator; sdk parser; core file endpoint; signals; storage hooks

### 📚 Documentation

- *(setup)* Wip, skeleton setup

## [0.2.1] - 2024-11-05

### 🐛 Bug Fixes

- *(deploy)* Fixed a bug in docker build

## [0.2.0] - 2024-11-05

### 🚀 Features

- *(sdk)* Added streaming to kitchenai SDK options. only for async functions

### ⚙️ Miscellaneous Tasks

- *(docs)* Added gifs to docs. re-word

## [0.1.1] - 2024-10-27

### 🐛 Bug Fixes

- *(cli)* Patching the dockerfile base image

## [0.1.0] - 2024-10-27

### 🚀 Features

- *(cli)* Added dynamic module import
- *(cli)* Added cook subcommand, list and select
- *(cli)* Kitchenai docker build command

### 🐛 Bug Fixes

- *(ci)* Ci has daisyui dependency added

### 🚜 Refactor

- *(homepage)* Cleaning up home page
- *(init)* Removed kitchenai yml from init requirement
- *(init)* Added superuser creation and periodic tasks to init
- *(cli)* Module import with run command

### ⚙️ Miscellaneous Tasks

- *(justfile)* Justfile push docker. COMPRESS_ENABLED

<!-- generated by git-cliff -->
